@@ -46,4 +46,4 @@ def test_get_tiddler_with_fields():
     assert tiddler_dict['uri'] == 'http://our_test_domain:8001/bags/bag0/tiddlers/feebles'
     assert tiddler_dict['fields']['field1'] == 'value1'
     assert tiddler_dict['fields']['field2'] == 'value2'
-    assert not tiddler_dict['fields'].has_key('server.first')
+    assert 'server.first' not in tiddler_dict['fields']
