@@ -1,5 +1,6 @@
 """
-JSON based serializer.
+:py:class:`Serialization <tiddlyweb.serializations.SerializationInterface>`
+for ``JSON``.
 """
 
 import simplejson
@@ -19,38 +20,53 @@ from tiddlyweb.web.util import tiddler_url
 
 class Serialization(SerializationInterface):
     """
-    Turn various entities to and from JSON.
+    Turn entities and collections thereof to and from ``JSON``.
     """
 
     def list_recipes(self, recipes):
         """
-        Create a JSON list of recipe names from
-        the provided recipes.
+        Create a ``JSON`` list of :py:class:`recipe
+        <tiddlyweb.model.recipe.Recipe>` names from the provided ``recipes``.
         """
         return simplejson.dumps([recipe.name for recipe in recipes])
 
     def list_bags(self, bags):
         """
-        Create a JSON list of bag names from the
-        provided bags.
+        Create a ``JSON`` list of :py:class:`bag <tiddlyweb.model.bag.Bag>`
+        names from the provided ``bags``.
         """
         return simplejson.dumps([bag.name for bag in bags])
 
     def list_tiddlers(self, tiddlers):
         """
-        List the tiddlers as JSON.
-        The format is a list of dicts in
-        the form described by self._tiddler_dict.
+        List the provided :py:class:`tiddlers
+        <tiddlyweb.model.tiddler.Tiddler>` as ``JSON``. The format is a
+        list of dicts in the form described by :py:func:`_tiddler_dict`.
+
+        If ``fat=1`` is set in ``tiddlyweb.query`` include the ``text``
+        of each tiddler in the output.
+
+        If ``render=1`` is set in ``tiddlyweb.query`` include the
+        :py:mod:`rendering <tiddlyweb.wikitext>` of the ``text``
+        of each tiddler in the output, if the tiddler is renderable.
         """
-        fat = self.environ.get('tiddlyweb.query', {}).get('fat', [False])[0]
-        render = self.environ.get('tiddlyweb.query', {}).get('render',
-                [False])[0]
+        query = self.environ.get('tiddlyweb.query', {})
+        fat = 0
+        render = 0
+        try:
+            fat = int(query.get('fat', [fat])[0])
+            render = int(query.get('render', [render])[0])
+        except ValueError:
+            pass
+
         return simplejson.dumps([self._tiddler_dict(tiddler, fat, render) for
             tiddler in tiddlers])
 
     def recipe_as(self, recipe):
         """
-        A recipe as a JSON dictionary.
+        A :py:class:`recipe <tiddlyweb.model.recipe.Recipe>` as a
+        ``JSON`` dictionary. Includes the recipe's :py:class:`policy
+        <tiddlyweb.model.policy.Policy>`.
         """
         policy_dict = dict([(key, getattr(recipe.policy, key)) for
                 key in Policy.attributes])
@@ -59,9 +75,9 @@ class Serialization(SerializationInterface):
 
     def as_recipe(self, recipe, input_string):
         """
-        Turn a JSON dictionary into a Recipe
-        if it is in the proper form. Include
-        the policy.
+        Turn a ``JSON`` dictionary into a :py:class:`recipe
+        <tiddlyweb.model.recipe.Recipe>` if it is in the proper form.
+        Include the :py:class:`policy <tiddlyweb.model.policy.Policy>`.
         """
         try:
             info = simplejson.loads(input_string)
@@ -79,8 +95,9 @@ class Serialization(SerializationInterface):
 
     def bag_as(self, bag):
         """
-        Create a JSON dictionary representing
-        a Bag and Policy.
+        A :py:class:`bag <tiddlyweb.model.bag.Bag>` as a
+        ``JSON`` dictionary. Includes the bag's :py:class:`policy
+        <tiddlyweb.model.policy.Policy>`.
         """
         policy_dict = dict([(key, getattr(bag.policy, key)) for
                 key in Policy.attributes])
@@ -89,7 +106,9 @@ class Serialization(SerializationInterface):
 
     def as_bag(self, bag, input_string):
         """
-        Turn a JSON string into a bag.
+        Turn a ``JSON`` dictionary into a :py:class:`bag
+        <tiddlyweb.model.bag.Bag>` if it is in the proper form.
+        Include the :py:class:`policy <tiddlyweb.model.policy.Policy>`.
         """
         try:
             info = simplejson.loads(input_string)
@@ -107,18 +126,33 @@ class Serialization(SerializationInterface):
 
     def tiddler_as(self, tiddler):
         """
-        Create a JSON dictionary representing
-        a tiddler, as described by _tiddler_dict
-        plus the text of the tiddler.
+        Create a ``JSON`` dictionary representing a tiddler, as described by
+        :py:func:`_tiddler_dict` plus the ``text`` of the tiddler.
+
+        If ``fat=0`` is set in ``tiddlyweb.query`` do not include the
+        ``text`` of the tiddler in the output.
+
+        If ``render=1`` is set in ``tiddlyweb.query`` include the
+        :py:mod:`rendering <tiddlyweb.wikitext>` of the ``text``
+        of the tiddler in the output, if the tiddler is renderable.
         """
-        render = self.environ.get('tiddlyweb.query', {}).get('render',
-                [False])[0]
-        tiddler_dict = self._tiddler_dict(tiddler, fat=True, render=render)
+        query = self.environ.get('tiddlyweb.query', {})
+        fat = 1
+        render = 0
+        try:
+            fat = int(query.get('fat', [fat])[0])
+            render = int(query.get('render', [render])[0])
+        except ValueError:
+            pass
+
+        tiddler_dict = self._tiddler_dict(tiddler, fat=fat, render=render)
         return simplejson.dumps(tiddler_dict)
 
     def as_tiddler(self, tiddler, input_string):
         """
-        Turn a JSON dictionary into a Tiddler.
+        Turn a ``JSON`` dictionary into a :py:class:`tiddler
+        <tiddlyweb.model.tiddler.Tiddler>`. Any keys in the ``JSON``
+        which are not recognized will be ignored.
         """
         try:
             dict_from_input = simplejson.loads(input_string)
@@ -158,9 +192,8 @@ class Serialization(SerializationInterface):
                 wanted_info['text'] = b64encode(tiddler.text)
             else:
                 wanted_info['text'] = tiddler.text
-                if render and renderable(tiddler, self.environ):
-                    wanted_info['render'] = render_wikitext(tiddler,
-                            self.environ)
+        if render and renderable(tiddler, self.environ):
+            wanted_info['render'] = render_wikitext(tiddler, self.environ)
         return wanted_info
 
     def _tiddler_permissions(self, tiddler):
