@@ -1,24 +1,25 @@
 """
-Functions for rendering anything that has been identified as wikitext
+Functions for rendering any :py:class:`tiddler
+<tiddlyweb.model.tiddler.Tiddler>` that has been identified as wikitext
 into the rendered form (usually HTML) of that wikitext.
 
 Wikitext rendering is engaged when a tiddler is requested via a
-GET, when the negotiated MIME-type of the request is html,
-and when tiddler.type is either none or in the keys of the
-dictionary associated with the tiddlyweb.config['wikitext.type_render_map'].
+``GET``, when the negotiated media-type of the request is html,
+and when ``tiddler.type`` is either ``None`` or in the keys of the
+dictionary associated with the
+:py:mod:`tiddlyweb.config['wikitext.type_render_map'] <tiddlyweb.config>`.
 
-When tiddler.type is none, the renderer named in
-tiddlyweb.config['wiktext_renderer'] is used. This is either a module
-in the tiddlyweb.wikitext package, or a module on sys.path.
+When ``tiddler.type`` is ``None``, the renderer named in
+``tiddlyweb.config['wiktext.default_renderer']`` is used. This is
+either a module in the :py:mod:`tiddlyweb.wikitext` package,
+or a module on ``sys.path``.
 
-When tiddler.type is something other than none, the renderer is
+When ``tiddler.type`` is something other than ``None``, the renderer is
 determined by looking up the type in
-tiddlyweb.config['wikitext.type_render_map']. The found value is a
+``tiddlyweb.config['wikitext.type_render_map']``. The found value is a
 module of the same type described above.
 
-The renderer module has a function render.
-
-NOTE: This interface is experimental and subject to change.
+The renderer module has a function ``render``.
 """
 
 DEFAULT_RENDERER = 'raw'
@@ -26,8 +27,8 @@ DEFAULT_RENDERER = 'raw'
 
 def render_wikitext(tiddler=None, environ=None):
     """
-    Take a tiddler and render its wikitext to some kind
-    of HTML format.
+    Take a :py:class:`tiddler <tiddlyweb.model.tiddler.Tiddler>`
+    and render wikitext in ``tiddler.text`` to some kind of HTML format.
     """
     if environ is None:
         environ = {}
@@ -47,9 +48,8 @@ def render_wikitext(tiddler=None, environ=None):
 
 def _determine_renderer(tiddler, environ):
     """
-    Inspect tiddlyweb.config to determine which
-    wikitext renderer should be used for this
-    tiddler.
+    Inspect ``tiddlyweb.config`` to determine which wikitext renderer
+    should be used for this tiddler.
     """
     config = environ.get('tiddlyweb.config', {})
     try:
